@@ -16,7 +16,10 @@
 // At present it is incomplete, but in future it should grow to contain
 // most or all target machine and target O/S specific information.
 #include "globals.h"
+#include "tokens.h"
 
+class ClassDeclaration;
+class Dsymbol;
 class Expression;
 class Type;
 class Module;
@@ -28,7 +31,6 @@ struct Target
     static int realsize;             // size a real consumes in memory
     static int realpad;              // 'padding' added to the CPU real size to bring it up to realsize
     static int realalignsize;        // alignment for reals
-    static bool realislongdouble;    // distinguish between C 'long double' and '__float128'
     static bool reverseCppOverloads; // with dmc and cl, overloaded functions are grouped and in reverse order
     static bool cppExceptions;       // set if catching C++ exceptions is supported
     static int c_longsize;           // size of a C 'long' or 'unsigned long' type
@@ -36,6 +38,17 @@ struct Target
     static int classinfosize;        // size of 'ClassInfo'
     static unsigned long long maxStaticDataSize;  // maximum size of static data
 
+#if IN_LLVM
+    struct FPTypeProperties
+    {
+        real_t max, min_normal, nan, snan, infinity, epsilon;
+        d_int64 dig, mant_dig, max_exp, min_exp, max_10_exp, min_10_exp;
+    };
+
+    static FPTypeProperties FloatProperties;
+    static FPTypeProperties DoubleProperties;
+    static FPTypeProperties RealProperties;
+#else
     template <typename T>
     struct FPTypeProperties
     {
@@ -56,9 +69,6 @@ struct Target
 
     typedef FPTypeProperties<float> FloatProperties;
     typedef FPTypeProperties<double> DoubleProperties;
-#if IN_LLVM
-    static FPTypeProperties<real_t> RealProperties;
-#else
     typedef FPTypeProperties<real_t> RealProperties;
 #endif
 
@@ -68,12 +78,17 @@ struct Target
     static unsigned fieldalign(Type *type);
     static unsigned critsecsize();
     static Type *va_listType();  // get type of va_list
-    static int checkVectorType(int sz, Type *type);
+    static int isVectorTypeSupported(int sz, Type *type);
+    static bool isVectorOpSupported(Type *type, TOK op, Type *t2 = NULL);
     // CTFE support for cross-compilation.
     static Expression *paintAsType(Expression *e, Type *type);
     // ABI and backend.
     static void loadModule(Module *m);
     static void prefixName(OutBuffer *buf, LINK linkage);
+    static const char *toCppMangle(Dsymbol *s);
+    static const char *cppTypeInfoMangle(ClassDeclaration *cd);
+    static const char *cppTypeMangle(Type *t);
+    static LINK systemLinkage();
 };
 
 #endif
