@@ -30,9 +30,6 @@ void freeRuntime();
 llvm::Function *getRuntimeFunction(const Loc &loc, llvm::Module &target,
                                    const char *name);
 
-llvm::GlobalVariable *getRuntimeGlobal(const Loc &loc, llvm::Module &target,
-                                       const char *name);
-
 void emitInstrumentationFnEnter(FuncDeclaration *decl);
 void emitInstrumentationFnLeave(FuncDeclaration *decl);
 
