@@ -24,6 +24,7 @@
 #include "gen/llvm.h"
 #include "gen/llvmhelpers.h"
 #include "gen/logger.h"
+#include "gen/mangling.h"
 #include "gen/nested.h"
 #include "gen/optimizer.h"
 #include "gen/pragma.h"
@@ -557,7 +558,7 @@ public:
     // valid array ops would have been transformed by optimize
     if ((t1->ty == Tarray || t1->ty == Tsarray) &&
         (t2->ty == Tarray || t2->ty == Tsarray)) {
-      base->error("Array operation %s not recognized", base->toChars());
+      base->error("Array operation `%s` not recognized", base->toChars());
       fatal();
     }
   }
@@ -987,14 +988,26 @@ public:
     auto &PGO = gIR->funcGen().pgo;
     PGO.setCurrentStmt(e);
 
+    VarDeclaration *vd = nullptr;
+
     // special cases: `this(int) { this(); }` and `this(int) { super(); }`
     if (!e->var) {
       Logger::println("this exp without var declaration");
-      result = new DLValue(e->type, p->func()->thisArg);
-      return;
+      if (auto thisArg = p->func()->thisArg) {
+        result = new DLValue(e->type, thisArg);
+        return;
+      }
+      // use the inner-most parent's `vthis`
+      for (int i = p->funcGenStates.size() - 2; i >= 0; --i) {
+        if (auto vthis = p->funcGenStates[i]->irFunc.decl->vthis) {
+          vd = vthis;
+          break;
+        }
+      }
+    } else {
+      vd = e->var->isVarDeclaration();
     }
 
-    const auto vd = e->var->isVarDeclaration();
     assert(vd);
     assert(!isSpecialRefVar(vd) && "Code not expected to handle special ref "
                                    "vars, although it can easily be made to.");
@@ -1343,6 +1356,9 @@ public:
         Logger::cout() << "rv: " << *rv << '\n';
       }
       eval = p->ir->CreateICmp(cmpop, lv, rv);
+      if (t->ty == Tvector) {
+        eval = mergeVectorEquals(eval, e->op);
+      }
     } else if (t->isfloating()) // includes iscomplex
     {
       eval = DtoBinNumericEquals(e->loc, l, r, e->op);
@@ -1684,8 +1700,8 @@ public:
 
       Logger::println("calling class invariant");
 
-      const auto fnMangle = gABI->mangleFunctionForLLVM(
-          "_D9invariant12_d_invariantFC6ObjectZv", LINKd);
+      const auto fnMangle =
+          getIRMangledFuncName("_D9invariant12_d_invariantFC6ObjectZv", LINKd);
       const auto fn = getRuntimeFunction(e->loc, gIR->module, fnMangle.c_str());
 
       const auto arg =
@@ -1870,8 +1886,8 @@ public:
     LOG_SCOPE;
 
     if (e->func->isStatic()) {
-      e->error("can't take delegate of static function %s, it does not require "
-               "a context ptr",
+      e->error("can't take delegate of static function `%s`, it does not "
+               "require a context ptr",
                e->func->toChars());
     }
 
@@ -2443,7 +2459,7 @@ public:
           getRuntimeFunction(e->loc, gIR->module, "_d_assocarrayliteralTX");
       LLFunctionType *funcTy = func->getFunctionType();
       LLValue *aaTypeInfo =
-          DtoBitCast(DtoTypeInfoOf(stripModifiers(aatype)),
+          DtoBitCast(DtoTypeInfoOf(stripModifiers(aatype), /*base=*/false),
                      DtoType(Type::typeinfoassociativearray->type));
 
       LLConstant *idxs[2] = {DtoConstUint(0), DtoConstUint(0)};
@@ -2545,7 +2561,7 @@ public:
   //////////////////////////////////////////////////////////////////////////////
 
   void visit(TypeExp *e) override {
-    e->error("type %s is not an expression", e->toChars());
+    e->error("type `%s` is not an expression", e->toChars());
     // TODO: Improve error handling. DMD just returns some value here and hopes
     // some more sensible error messages will be triggered.
     fatal();
@@ -2627,7 +2643,7 @@ public:
     IF_LOG Logger::print("PowExp::toElem() %s\n", e->toChars());
     LOG_SCOPE;
 
-    e->error("must import std.math to use ^^ operator");
+    e->error("must import `std.math` to use `^^` operator");
     result = new DNullValue(e->type, llvm::UndefValue::get(DtoType(e->type)));
   }
 
@@ -2674,7 +2690,7 @@ public:
 
 #define STUB(x)                                                                \
   void visit(x *e) override {                                                  \
-    e->error("Internal compiler error: Type " #x " not implemented: %s",       \
+    e->error("Internal compiler error: Type `" #x "` not implemented: `%s`",   \
              e->toChars());                                                    \
     fatal();                                                                   \
   }
@@ -2720,16 +2736,34 @@ bool toInPlaceConstruction(DLValue *lhs, Expression *rhs) {
       rhs = castSource;
   }
 
-  // Direct construction by rhs call via sret?
-  // E.g., `T v = foo();` if the callee `T foo()` uses sret.
-  // In this case, pass `&v` as hidden sret argument, i.e., let `foo()`
-  // construct the return value directly into the lhs lvalue.
   if (rhs->op == TOKcall) {
     auto ce = static_cast<CallExp *>(rhs);
+
+    // Direct construction by rhs call via sret?
+    // E.g., `T v = foo();` if the callee `T foo()` uses sret.
+    // In this case, pass `&v` as hidden sret argument, i.e., let `foo()`
+    // construct the return value directly into the lhs lvalue.
     if (DtoIsReturnInArg(ce)) {
       ToElemVisitor::call(gIR, ce, DtoLVal(lhs));
       return true;
     }
+
+    // DMD issue 17457: detect structliteral.ctor(args)
+    if (ce->e1->op == TOKdotvar) {
+      auto dve = static_cast<DotVarExp *>(ce->e1);
+      auto fd = dve->var->isFuncDeclaration();
+      if (fd && fd->isCtorDeclaration() && dve->e1->op == TOKstructliteral) {
+        // emit the struct literal directly into the lhs lvalue...
+        auto sle = static_cast<StructLiteralExp *>(dve->e1);
+        auto lval = DtoLVal(lhs);
+        ToElemVisitor::emitStructLiteral(sle, lval);
+        // ... and invoke the ctor directly on it
+        DtoDeclareFunction(fd);
+        auto fnval = new DFuncValue(fd, DtoCallee(fd), lval);
+        DtoCallFunction(ce->loc, ce->type, fnval, ce->arguments);
+        return true;
+      }
+    }
   }
 
   // emit struct literals directly into the lhs lvalue
